@@ -97,7 +97,7 @@ sub hours
 sub remove_strings
 {
     return (
-        qr{\sde\s}i,                 # remove ' de ' as in '29 de febrero de 1996'
+        qr{\bde\b}i, # remove ' de ' as in '29 de febrero de 1996'
     );
 }
 
@@ -115,13 +115,10 @@ sub string_dates
         hoy    => sub { return $base_dt->clone->truncate( to => 'day' )->ymd } ,                       # today
         manana => sub { return $base_dt->clone->truncate( to => 'day' )->add( days => 1 )->ymd },      # tomorrow
         ayer   => sub { return $base_dt->clone->truncate( to => 'day' )->subtract( days => 1 )->ymd }, # yesterday
-        'pasado manana' => sub { return DateTime->today->add( days => 2 )->ymd },      # overmorrow (the day after tomorrow)
+        'pasado manana' => sub { return DateTime->today->add( days => 2 )->ymd },                      # overmorrow (the day after tomorrow)
         epoca       => sub { return DateTime->from_epoch( epoch => 0 ) },
-        '-infinito' => sub { return DateTime::Infinite::Past->new },
-        infinito    => sub { return DateTime::Infinite::Future->new },
-
-
-
+        '-infinito' => sub { return '-infinity' },
+        infinito    => sub { return 'infinity'  },
     );
 }
 
@@ -229,10 +226,10 @@ maps unofficial timezones to official timezones for this language (PDT  => Ameri
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright 2010 Tom Heady.
+Copyright 2010 Tom Heady.
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of either:
+This program is free software; you can redistribute it and/or
+modify it under the terms of either:
 
 =over 4
 
